@@ -11,6 +11,9 @@
 
 Controller::Controller(QObject *parent) :
     QObject(parent) {
+    converter = new QProcess(this);
+    connect(converter, SIGNAL(started()), this, SIGNAL(conversionStarted()));
+    connect(converter, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(conversionFinished(int, QProcess::ExitStatus)));
 }
 
 void Controller::setView(QmlApplicationViewer *view) {
@@ -90,3 +93,32 @@ void Controller::deleteVideo(const QString &path) {
         emit alert("Video not found");
     }
 }
+
+void Controller::convertToAudio(const QString &input) {
+    inputFile = input;
+    QString ffmpeg = "/usr/bin/ffmpeg";
+    QStringList args;
+    outputFile = input;
+    outputFile.replace(".mp4", ".m4a");
+    args << "-i" << inputFile << "-acodec" << "copy" << "-y" << "-vn" << outputFile;
+
+    converter->start(ffmpeg, args);
+}
+
+void Controller::conversionFinished(int exitCode, QProcess::ExitStatus exitStatus) {
+
+    if ((exitCode == 0) && (exitStatus == QProcess::NormalExit)) {
+        QFile output(outputFile);
+        if (output.size() > 0) {
+            emit conversionCompleted();
+            QFile::remove(inputFile);
+        }
+        else {
+            emit conversionFailed();
+            QFile::remove(outputFile);
+        }
+    }
+    else {
+        emit conversionFailed();
+    }
+}
