@@ -2,6 +2,7 @@
 #define CONTROLLER_H
 
 #include <QObject>
+#include <QProcess>
 
 class QWidget;
 
@@ -25,15 +26,23 @@ public slots:
     void minimize();
     void playVideo(const QString &url);
     void deleteVideo(const QString &path);
+    void convertToAudio(const QString &input);
+
+private slots:
+    void conversionFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
 private:
     QmlApplicationViewer* m_view;
     QString mediaPlayer;
+    QProcess *converter;
+    QString inputFile;
+    QString outputFile;
 
 signals:
     void alert(const QString &message);
-
-
+    void conversionStarted();
+    void conversionCompleted();
+    void conversionFailed();
 };
 
 #endif // CONTROLLER_H
